@@ -2,11 +2,15 @@ import platform
 import os
 import subprocess
 import math
+import time
 from typing import Optional, Tuple
+from .logging_utils import get_logger, log_exception
 
 
 # ===== Conditional Imports via Windows and macOS =====
 _WINDOWS_IMPORTS_AVAILABLE = False
+logger = get_logger()
+logger.info("window_actions module imported")
 if platform.system() == 'Windows':
     try:
         import ctypes
@@ -18,6 +22,7 @@ if platform.system() == 'Windows':
         _WINDOWS_IMPORTS_AVAILABLE = True
     except Exception as e:
         # This now Indicates a *Broken Installation*, Not Something to Fix at Runtime
+        log_exception("Windows backend import failure")
         raise RuntimeError(
             "Windows Backend Requested But pywin32 is Not Installed. "
             "Reinstall the Package on Windows."
@@ -47,6 +52,7 @@ if platform.system() == 'Darwin':
         _MACOS_IMPORTS_AVAILABLE = True
     except Exception as e:
         # This now Indicates a *Broken Installation*, Not Something to Fix at Runtime
+        log_exception("macOS backend import failure")
         raise RuntimeError(
             "macOS Backend Requested But PyObjC Frameworks are Missing. "
             "Reinstall This Package on macOS so the Platform Deps Resolve."
@@ -88,30 +94,50 @@ def execute_os(mac_command, win_command):
     os_name = platform.system()
 
     if os_name == 'Darwin':
+        logger.debug("execute_os -> macOS path")
         return mac_command
     elif os_name == 'Windows': 
+        logger.debug("execute_os -> Windows path")
         return win_command
     else:
-        print("Unsupported Operating System (Not MacOS or Windows)")
+        logger.warning("Unsupported Operating System (Not MacOS or Windows)")
         return False
 # ===== Common Exclusion Helpers =====
 def _excluded_list():
+    """返回需要忽略的AI软件列表"""
     raw = "AIdo,com.silicon-geek.aido,aido.exe,aido"
     return [s.strip().lower() for s in raw.split(",") if s.strip()]
 
 def _is_excluded_name(name: Optional[str]) -> bool:
+    """检查应用名称是否在忽略列表中"""
     if not name:
         return False
-    return name.lower() in _excluded_list()
+    name_lower = name.lower()
+    excluded = _excluded_list()
+    
+    # 精确匹配
+    if name_lower in excluded:
+        return True
+    
+    # 部分匹配（用于处理版本号等变化）
+    for excluded_name in excluded:
+        if excluded_name in name_lower or name_lower in excluded_name:
+            return True
+    
+    return False
 
 
 
 # ===== macOS Helper Functions =====
 def _focused_window_for_actions():
+    logger.info("_focused_window_for_actions: locating frontmost app")
     ax_app = _frontmost_ax_app()
     if not ax_app:
+        logger.warning("_focused_window_for_actions: no frontmost app")
         return None
-    return _focused_or_standard_window(ax_app)
+    win = _focused_or_standard_window(ax_app)
+    logger.info(f"_focused_window_for_actions: window found? {bool(win)}")
+    return win
 
 def _ax_copy(el, attr):
     res = AXUIElementCopyAttributeValue(el, attr, None)
@@ -120,15 +146,29 @@ def _ax_copy(el, attr):
     return res
 
 def _do_region(region: str) -> bool:
+    logger.info(f"_do_region: region={region}")
     ax_app = _frontmost_ax_app()
     if not ax_app:
+        logger.warning("_do_region: no frontmost app")
         return False
     win = _focused_or_standard_window(ax_app)
     if not _prep_window(win):
+        logger.warning("_do_region: window not resizable or invalid")
         return False
-    screen = _pick_screen_for(win)
-    x, y, w, h = _target_frame_for_screen_region(screen, region)
-    return _tile(win, x, y, w, h)
+
+    # 优先通过 CGWindow 的前台窗口边界来选屏，避免因历史位置导致选屏不准
+    info = _frontmost_app_info()
+    cg_center = _frontmost_window_bounds_center_via_cg(info.get('pid') if info else None)
+    if cg_center:
+        scr = _screen_for_point(cg_center[0], cg_center[1])
+    else:
+        scr = _pick_screen_for(win)
+
+    x, y, w, h = _target_frame_for_screen_region(scr, region)
+    logger.info(f"_do_region: target frame x={x} y={y} w={w} h={h}")
+    ok = _tile(win, x, y, w, h)
+    logger.info(f"_do_region: tile result={ok}")
+    return ok
 
 def _send_keystroke_control_command_f():
     KEY_F = 0x03
@@ -208,6 +248,7 @@ def _frontmost_pid_applescript() -> Optional[int]:
             app_name = result.stdout.strip()
             # Exclude by app name first
             if app_name and app_name.lower() in _excluded_list():
+                logger.info(f"_frontmost_pid_applescript: excluded app_name={app_name}")
                 return None
             
             # Get the PID for this app name
@@ -222,32 +263,187 @@ def _frontmost_pid_applescript() -> Optional[int]:
                     except Exception:
                         bid = None
                     if bid and bid.lower() in _excluded_list():
+                        logger.info(f"_frontmost_pid_applescript: excluded bundle={bid}")
                         return None
-                    return int(app.processIdentifier())
+                    pid = int(app.processIdentifier())
+                    logger.info(f"_frontmost_pid_applescript: pid={pid} name={app_name} bundle={bid}")
+                    return pid
                     
     except Exception:
         pass
     
     # Fallback to original method
-    return _frontmost_pid()
+    pid = _frontmost_pid()
+    logger.info(f"_frontmost_pid_applescript: fallback pid={pid}")
+    return pid
+
+def _ax_app_for_app_name(app_name: str):
+    try:
+        workspace = NSWorkspace.sharedWorkspace()
+        for app in workspace.runningApplications():
+            try:
+                if app.localizedName() == app_name:
+                    pid = int(app.processIdentifier())
+                    try:
+                        return AXUIElementCreateApplication(pid)
+                    except Exception:
+                        log_exception("AXUIElementCreateApplication failed (by name)")
+                        return None
+            except Exception:
+                continue
+    except Exception:
+        return None
+    return None
+
+
+# 尝试引入 CGWindow API（用于前台窗口更精确检测）
+try:
+    from Quartz import (
+        CGWindowListCopyWindowInfo,
+        kCGWindowListOptionOnScreenOnly,
+        kCGWindowListExcludeDesktopElements,
+    )
+    _CGWINDOW_AVAILABLE = True
+except Exception:
+    _CGWINDOW_AVAILABLE = False
+
+
+def _frontmost_app_via_cg() -> Optional[dict]:
+    """使用 CGWindow 列表判断屏幕最前的普通窗口所属应用。
+    返回 {'pid': int, 'name': str}，失败返回 None。
+    """
+    if not _CGWINDOW_AVAILABLE:
+        return None
+    try:
+        options = kCGWindowListOptionOnScreenOnly | kCGWindowListExcludeDesktopElements
+        infos = CGWindowListCopyWindowInfo(options, 0) or []
+        # 过滤正常窗口：非全透明、拥有者存在、尺寸大于零
+        for info in infos:
+            owner_name = info.get('kCGWindowOwnerName')
+            owner_pid = info.get('kCGWindowOwnerPID')
+            alpha = info.get('kCGWindowAlpha', 1)
+            bounds = info.get('kCGWindowBounds') or {}
+            w = int(bounds.get('Width', 0) or 0)
+            h = int(bounds.get('Height', 0) or 0)
+            if not owner_name or not owner_pid:
+                continue
+            if alpha == 0 or w <= 1 or h <= 1:
+                continue
+            # 命中未忽略应用即返回
+            if not _is_excluded_name(str(owner_name)):
+                return {'pid': int(owner_pid), 'name': str(owner_name), 'bundle': None}
+        return None
+    except Exception:
+        return None
+
+
+def _frontmost_app_info() -> Optional[dict]:
+    """综合 AppleScript 与 CGWindow，返回最可信的前台应用信息。
+    优先 AppleScript；若结果为壳/被忽略且 CGWindow 提供了更可信的未忽略应用，则采用 CGWindow。
+    结构: {'pid': int, 'name': str|None, 'bundle': str|None}
+    """
+    applescript_info = None
+    try:
+        # AppleScript: get true frontmost app name
+        script = '''
+        tell application "System Events"
+            set frontApp to name of first application process whose frontmost is true
+            return frontApp
+        end tell
+        '''
+        res = subprocess.run(['osascript', '-e', script], capture_output=True, text=True, timeout=2)
+        if res.returncode == 0 and res.stdout.strip():
+            app_name = res.stdout.strip()
+            workspace = NSWorkspace.sharedWorkspace()
+            for app in workspace.runningApplications():
+                try:
+                    if app.localizedName() == app_name:
+                        try:
+                            bid = app.bundleIdentifier()
+                        except Exception:
+                            bid = None
+                        pid = int(app.processIdentifier())
+                        applescript_info = {'pid': pid, 'name': app_name, 'bundle': bid}
+                        break
+                except Exception:
+                    continue
+    except Exception:
+        applescript_info = None
+
+    cg_info = _frontmost_app_via_cg()
+
+    # 决策：
+    # 1) 如果 AppleScript 为空而 CG 有结果（未忽略），用 CG
+    if not applescript_info and cg_info and not _is_excluded_name(cg_info.get('name')):
+        logger.info(f"_frontmost_app_info: using CGWindow '{cg_info.get('name')}' pid={cg_info.get('pid')}")
+        return cg_info
+
+    # 2) 如果 AppleScript 有结果，但命中忽略或疑似壳（如 Cursor），且 CG 返回未忽略窗口，则用 CG
+    def _is_shell_like(name: Optional[str]) -> bool:
+        if not name:
+            return False
+        name_lower = name.lower()
+        return any(shell in name_lower for shell in ("cursor", "todesk", "electron"))
+
+    if applescript_info:
+        asp_name = applescript_info.get('name')
+        asp_bundle = applescript_info.get('bundle')
+        if (_is_shell_like(asp_name) or _is_excluded_name(asp_name) or _is_excluded_name(asp_bundle)) and cg_info and not _is_excluded_name(cg_info.get('name')):
+            logger.info(f"_frontmost_app_info: prefer CGWindow '{cg_info.get('name')}' over AppleScript '{asp_name}'")
+            return cg_info
+        # 否则采用 AppleScript
+        return applescript_info
+
+    # 3) 都没有，返回 None
+    return None
+
 
 def _frontmost_ax_app():
-    # 优先返回当前前台未被排除的应用；若被排除，则尝试激活下一个未排除应用
-    ax = _frontmost_ax_app_raw()
-    if ax and not _is_excluded_current_app():
-        return ax
-    # 如果当前应用被排除，直接返回None，不要激活其他应用
-    if _is_excluded_current_app():
-        return None
+    # 1) 优先使用综合策略获取“真正前台应用”
+    info = _frontmost_app_info()
+    if info:
+        name = info.get('name')
+        bundle = info.get('bundle')
+        pid = info.get('pid')
+        if not _is_excluded_name(name) and not _is_excluded_name(bundle):
+            try:
+                ax = AXUIElementCreateApplication(pid)
+                if ax:
+                    logger.info(f"_frontmost_ax_app: using app '{name}' pid={pid}")
+                    return ax
+            except Exception:
+                log_exception("AXUIElementCreateApplication failed (by best-frontmost pid)")
+
+    # 2) 回退：可见列表中挑选未忽略应用（不激活）
+    names = _ordered_visible_app_names()
+    for name in names:
+        if not _is_excluded_name(name):
+            ax_candidate = _ax_app_for_app_name(name)
+            if ax_candidate:
+                logger.info(f"_frontmost_ax_app: selected visible unexcluded app '{name}' without activation")
+                return ax_candidate
+
+    # 3) 兜底：激活第一个未忽略应用 + 重试
     if _activate_next_unexcluded_app():
-        ax = _frontmost_ax_app_raw()
-        if ax and not _is_excluded_current_app():
-            return ax
+        time.sleep(0.2)
+        for _ in range(12):
+            ax = _frontmost_ax_app_raw()
+            if ax and not _is_excluded_current_app():
+                logger.info("_frontmost_ax_app: acquired after activation+retry")
+                return ax
+            time.sleep(0.1)
+
     return None
 
 def _frontmost_ax_app_raw():
     pid = _frontmost_pid_applescript()
-    return AXUIElementCreateApplication(pid) if pid else None
+    if not pid:
+        return None
+    try:
+        return AXUIElementCreateApplication(pid)
+    except Exception:
+        log_exception("AXUIElementCreateApplication failed")
+        return None
 
 def _is_excluded_current_app() -> bool:
     try:
@@ -311,6 +507,7 @@ def _activate_next_unexcluded_app() -> bool:
     for name in names:
         if not _is_excluded_name(name):
             if _activate_app_by_name(name):
+                logger.info(f"_activate_next_unexcluded_app: activated {name}")
                 return True
     return False
 
@@ -346,6 +543,7 @@ def _tile(win, x: float, y: float, w: float, h: float) -> bool:
             AXUIElementSetAttributeValue(win, AX_POSITION, _ax_point(x, y))
             return True
         except Exception:
+            logger.warning("_tile: failed to set AX attributes")
             return False
 
 def _target_frame_for_screen_region(screen, region: str) -> Tuple[float, float, float, float]:
@@ -360,25 +558,26 @@ def _target_frame_for_screen_region(screen, region: str) -> Tuple[float, float,
     """
     v = screen.visibleFrame()  # respects menu bar & Dock
     vX, vY, vW, vH = float(v.origin.x), float(v.origin.y), float(v.size.width), float(v.size.height)
-    # 修复坐标系转换：macOS使用底部左下角为原点，但AX使用顶部左上角
+    # macOS坐标系：visibleFrame已经返回正确的坐标，无需转换
     axTopLeftY = vY
 
     if region in ("left", "right"):
-        halfW = float(int(vW // 2))
+        # 使用精确的浮点计算，然后四舍五入
+        halfW = round(vW / 2.0)
         if region == "left":
             return (vX, axTopLeftY, halfW, vH)
         else:
             return (vX + halfW, axTopLeftY, vW - halfW, vH)
 
     elif region in ("top", "bottom"):
-        halfH = float(int(vH // 2))
+        halfH = round(vH / 2.0)
         if region == "top":
             return (vX, axTopLeftY, vW, halfH)
         else:
             return (vX, axTopLeftY + halfH, vW, vH - halfH)
 
     elif region in ("left_third", "middle_third", "right_third"):
-        thirdW = float(int(vW // 3))
+        thirdW = round(vW / 3.0)
         if region == "left_third":
             return (vX, axTopLeftY, thirdW, vH)
         elif region == "middle_third":
@@ -387,7 +586,7 @@ def _target_frame_for_screen_region(screen, region: str) -> Tuple[float, float,
             return (vX + 2*thirdW, axTopLeftY, vW - 2*thirdW, vH)
     
     elif region in ("left_two_third", "right_two_third"):
-        thirdW = float(int(vW // 3))
+        thirdW = round(vW / 3.0)
         if region == "left_two_third":
             # start at left edge, take two-thirds
             return (vX, axTopLeftY, 2*thirdW, vH)
@@ -399,8 +598,8 @@ def _target_frame_for_screen_region(screen, region: str) -> Tuple[float, float,
         "top_left_quarter", "top_right_quarter",
         "bottom_left_quarter", "bottom_right_quarter"
     ):
-        halfW = float(vW // 2)
-        halfH = float(vH // 2)
+        halfW = round(vW / 2.0)
+        halfH = round(vH / 2.0)
 
         if region == "top_left_quarter":
             return (vX, axTopLeftY, halfW, halfH)
@@ -419,6 +618,7 @@ def _target_frame_for_screen_region(screen, region: str) -> Tuple[float, float,
         return (vX, axTopLeftY, vW, vH)
     
     else:
+        logger.error(f"Unknown region: {region}")
         raise ValueError(f"Unknown region: {region}")
 
 def _prep_window(win) -> bool:
@@ -435,7 +635,13 @@ def _pick_screen_for(win):
     pos = _ax_get_point(win, AX_POSITION) or (0.0, 0.0)
     size = _ax_get_size(win, AX_SIZE) or (0.0, 0.0)
     cx, cy = pos[0] + size[0]/2.0, pos[1] + size[1]/2.0
-    return _screen_for_point(cx, cy)
+    scr = _screen_for_point(cx, cy)
+    try:
+        f = scr.frame()
+        logger.info(f"_pick_screen_for: window center=({cx},{cy}) screen=({f.origin.x},{f.origin.y},{f.size.width},{f.size.height})")
+    except Exception:
+        pass
+    return scr
 
 
 # ===== Windows Helper Functions =====
@@ -443,20 +649,27 @@ def check_exit_fullscreen_win(hwnd):
     """Restore if Window is Maximized so it can be Resized/Moved."""
     placement = win32gui.GetWindowPlacement(hwnd)
     if placement[1] == win32con.SW_SHOWMAXIMIZED:
+        logger.info("check_exit_fullscreen_win: restoring from maximized state")
         win32gui.ShowWindow(hwnd, win32con.SW_RESTORE)
 
+
 def set_dpi_aware_win():
     """Ensure Coordinates Match Physical Pixels on High-DPI Displays."""
     try:
         ctypes.windll.user32.SetProcessDPIAware()
+        logger.debug("set_dpi_aware_win: SetProcessDPIAware OK")
     except Exception:
-        pass
+        logger.warning("set_dpi_aware_win: SetProcessDPIAware failed")
+
 
 def get_effective_dimension_win(hwnd):
     """(L, T, R, B) for the Monitor Containing hwnd, Excluding Taskbar."""
     monitor = win32api.MonitorFromWindow(hwnd, win32con.MONITOR_DEFAULTTONEAREST)
     mi = win32api.GetMonitorInfo(monitor)  # Keys: "Monitor" & "Work"
-    return mi['Work']
+    work = mi['Work']
+    logger.info(f"get_effective_dimension_win: work={work}")
+    return work
+
 
 def get_visible_frame_win(hwnd):
     """
@@ -471,8 +684,13 @@ def get_visible_frame_win(hwnd):
         ctypes.sizeof(rect),
     )
     if hr == 0:
-        return rect.left, rect.top, rect.right, rect.bottom
-    return win32gui.GetWindowRect(hwnd)
+        out = (rect.left, rect.top, rect.right, rect.bottom)
+        logger.debug(f"get_visible_frame_win: DWM bounds={out}")
+        return out
+    out = win32gui.GetWindowRect(hwnd)
+    logger.debug(f"get_visible_frame_win: fallback GetWindowRect={out}")
+    return out
+
 
 def apply_effective_bounds_win(hwnd, target_ltrb):
     """
@@ -483,9 +701,11 @@ def apply_effective_bounds_win(hwnd, target_ltrb):
     W = max(1, R - L)
     H = max(1, B - T)
 
+    logger.info(f"apply_effective_bounds_win: target LTRB=({L},{T},{R},{B}) size=({W},{H})")
+
     win32gui.SetWindowPos(
         hwnd, 0, L, T, W, H,
-        win32con.SWP_NOZORDER | win32con.SWP_NOACTIVATE | win32con.SWP_SHOWWINDOW
+        win32con.SWP_NOZORDER | win32con.SWP_NOACTIVATE | win32con.SWP_SHOWWINDOW | win32con.SWP_FRAMECHANGED
     )
 
     visL, visT, visR, visB = get_visible_frame_win(hwnd)
@@ -506,11 +726,38 @@ def apply_effective_bounds_win(hwnd, target_ltrb):
     corrW = max(1, int(round(corrW)))
     corrH = max(1, int(round(corrH)))
 
+    logger.debug(f"apply_effective_bounds_win: correction to LTRB=({corrL},{corrT},{corrL+corrW},{corrT+corrH})")
+
     win32gui.SetWindowPos(
         hwnd, 0, corrL, corrT, corrW, corrH,
-        win32con.SWP_NOZORDER | win32con.SWP_NOACTIVATE | win32con.SWP_SHOWWINDOW
+        win32con.SWP_NOZORDER | win32con.SWP_NOACTIVATE | win32con.SWP_SHOWWINDOW | win32con.SWP_FRAMECHANGED
     )
 
+
+def _bring_window_to_front_win(hwnd):
+    """Best-effort bring-to-front for target window before moving/resizing."""
+    try:
+        # If minimized or maximized, restore to normal so it can be resized
+        placement = win32gui.GetWindowPlacement(hwnd)
+        if placement and placement[1] in (win32con.SW_SHOWMINIMIZED, win32con.SW_SHOWMAXIMIZED):
+            logger.info("_bring_window_to_front_win: restoring window state")
+            win32gui.ShowWindow(hwnd, win32con.SW_RESTORE)
+    except Exception:
+        logger.debug("_bring_window_to_front_win: restore failed")
+    try:
+        win32gui.BringWindowToTop(hwnd)
+    except Exception:
+        logger.debug("_bring_window_to_front_win: BringWindowToTop failed")
+    try:
+        win32gui.SetForegroundWindow(hwnd)
+    except Exception:
+        # Foreground lock timeout may block; try activating
+        try:
+            win32gui.SetActiveWindow(hwnd)
+        except Exception:
+            logger.debug("_bring_window_to_front_win: SetActiveWindow failed")
+
+
 def apply_window_fraction_win(rx, ry, rw, rh):
     """
     Snap the Foreground Window to a Rectangle Expressed as Fractions
@@ -519,23 +766,40 @@ def apply_window_fraction_win(rx, ry, rw, rh):
     set_dpi_aware_win()
     hwnd = _get_top_visible_unexcluded_window()
     if not hwnd:
+        logger.warning("apply_window_fraction_win: no suitable hwnd found")
         raise RuntimeError("No visible unexcluded foreground window found.")
 
+    logger.info(f"apply_window_fraction_win: hwnd={hwnd}")
+
+    _bring_window_to_front_win(hwnd)
     check_exit_fullscreen_win(hwnd)
 
     waL, waT, waR, waB = get_effective_dimension_win(hwnd)
     waW = waR - waL
     waH = waB - waT
 
-    L = waL + int(math.floor(waW * rx))
-    T = waT + int(math.floor(waH * ry))
-    R = waL + int(math.floor(waW * (rx + rw)))
-    B = waT + int(math.floor(waH * (ry + rh)))
+    # 修复Windows坐标计算，确保精确的像素对齐
+    L = waL + int(round(waW * rx))
+    T = waT + int(round(waH * ry))
+    R = waL + int(round(waW * (rx + rw)))
+    B = waT + int(round(waH * (ry + rh)))
 
+    # 确保窗口至少有一个像素的宽度和高度
     R = max(R, L + 1)
     B = max(B, T + 1)
 
-    apply_effective_bounds_win(hwnd, (L, T, R, B))
+    logger.info(f"apply_window_fraction_win: computed LTRB=({L},{T},{R},{B})")
+
+    try:
+        apply_effective_bounds_win(hwnd, (L, T, R, B))
+    except Exception:
+        log_exception("apply_window_fraction_win: failed to apply bounds")
+        raise
+
+    final_rect = win32gui.GetWindowRect(hwnd)
+    logger.info(f"apply_window_fraction_win: final rect={final_rect}")
+
+
 # Windows exclusion checker
 def _is_excluded_windows(hwnd) -> bool:
     ex = _excluded_list()
@@ -547,6 +811,7 @@ def _is_excluded_windows(hwnd) -> bool:
         title = ""
     # Title substring match
     if title and any(e in title for e in ex):
+        logger.debug(f"_is_excluded_windows: excluded by title '{title}'")
         return True
     # Process executable name/path match
     try:
@@ -559,28 +824,37 @@ def _is_excluded_windows(hwnd) -> bool:
         exe_path = win32process.GetModuleFileNameEx(hproc, 0) if hproc else ""
         exe_name = os.path.basename(exe_path).lower() if exe_path else ""
         if exe_name and exe_name in ex:
+            logger.debug(f"_is_excluded_windows: excluded by exe '{exe_name}'")
             return True
         if exe_path and any(e in exe_path.lower() for e in ex):
+            logger.debug(f"_is_excluded_windows: excluded by path '{exe_path}'")
             return True
     except Exception:
         pass
     return False
 
+
 def _get_top_visible_unexcluded_window():
     try:
         # Start from foreground
         hwnd = win32gui.GetForegroundWindow()
+        logger.info(f"_get_top_visible_unexcluded_window: start hwnd={hwnd}")
         # Iterate Z-order backwards using GetWindow with GW_HWNDPREV
         GW_HWNDPREV = 3
         visited = set()
-        while hwnd and hwnd not in visited:
+        step = 0
+        while hwnd and hwnd not in visited and step < 100:
             visited.add(hwnd)
+            step += 1
             if win32gui.IsWindowVisible(hwnd) and win32gui.IsWindow(hwnd):
                 if not _is_excluded_windows(hwnd):
+                    logger.info(f"_get_top_visible_unexcluded_window: choose hwnd={hwnd} after {step} steps")
                     return hwnd
+                else:
+                    logger.debug(f"_get_top_visible_unexcluded_window: excluded hwnd={hwnd}")
             hwnd = win32gui.GetWindow(hwnd, GW_HWNDPREV)
     except Exception:
-        pass
+        log_exception("_get_top_visible_unexcluded_window: failed")
     return None
 
 
@@ -646,7 +920,9 @@ def maximise_window_win():
     hwnd = _get_top_visible_unexcluded_window()
     if not hwnd:
         raise RuntimeError("No visible unexcluded foreground window found.")
+    logger.info(f"maximise_window_win: hwnd={hwnd}")
     win32gui.ShowWindow(hwnd, win32con.SW_MAXIMIZE)
+    return True
 
 
 # ===== (Tool 03) Fullscreen Window =====
@@ -685,7 +961,9 @@ def fullscreen_window_win():
     hwnd = _get_top_visible_unexcluded_window()
     if not hwnd:
         raise RuntimeError("No visible unexcluded foreground window found.")
+    logger.info(f"fullscreen_window_win: hwnd={hwnd}")
     win32gui.ShowWindow(hwnd, win32con.SW_MAXIMIZE)
+    return True
 
 
 # ===== (Tool 04) Left 1/2 Screen =====
@@ -698,6 +976,7 @@ def left_half_window_mac() -> bool:
 
 def left_half_window_win():
     apply_window_fraction_win(0.0, 0.0, 0.5, 1.0)
+    return True
 
 
 # ===== (Tool 05) Right 1/2 Screen =====
@@ -710,6 +989,7 @@ def right_half_window_mac() -> bool:
 
 def right_half_window_win():
     apply_window_fraction_win(0.5, 0.0, 0.5, 1.0)
+    return True
 
 
 # ===== (Tool 06) Left 1/3 Screen =====
@@ -722,6 +1002,7 @@ def left_third_window_mac() -> bool:
 
 def left_third_window_win():
     apply_window_fraction_win(0.0, 0.0, 1.0/3.0, 1.0)
+    return True
 
 
 # ===== (Tool 07) Middle 1/3 Screen =====
@@ -734,6 +1015,7 @@ def middle_third_window_mac() -> bool:
 
 def middle_third_window_win():
     apply_window_fraction_win(1.0/3.0, 0.0, 1.0/3.0, 1.0)
+    return True
 
 
 # ===== (Tool 08) Right 1/3 Screen =====
@@ -746,6 +1028,7 @@ def right_third_window_mac() -> bool:
 
 def right_third_window_win():
     apply_window_fraction_win(2.0/3.0, 0.0, 1.0/3.0, 1.0)
+    return True
 
 
 # ===== (Tool 09) Top 1/2 Screen =====
@@ -758,6 +1041,7 @@ def top_half_window_mac() -> bool:
 
 def top_half_window_win():
     apply_window_fraction_win(0.0, 0.0, 1.0, 0.5)
+    return True
 
 
 # ===== (Tool 10) Bottom 1/2 Screen =====
@@ -770,6 +1054,7 @@ def bottom_half_window_mac() -> bool:
 
 def bottom_half_window_win():
     apply_window_fraction_win(0.0, 0.5, 1.0, 0.5)
+    return True
 
 
 # ===== (Tool 11) Top Left 1/4 Screen =====
@@ -782,6 +1067,7 @@ def top_left_quadrant_window_mac() -> bool:
 
 def top_left_quadrant_window_win():
     apply_window_fraction_win(0.0, 0.0, 0.5, 0.5)
+    return True
 
 
 # ===== (Tool 12) Top Right 1/4 Screen =====
@@ -794,6 +1080,7 @@ def top_right_quadrant_window_mac() -> bool:
 
 def top_right_quadrant_window_win():
     apply_window_fraction_win(0.5, 0.0, 0.5, 0.5)
+    return True
 
 
 # ===== (Tool 13) Bottom Left 1/4 Screen =====
@@ -806,6 +1093,7 @@ def bottom_left_quadrant_window_mac() -> bool:
 
 def bottom_left_quadrant_window_win():
     apply_window_fraction_win(0.0, 0.5, 0.5, 0.5)
+    return True
 
 
 # ===== (Tool 14) Bottom Right 1/4 Screen =====
@@ -818,6 +1106,7 @@ def bottom_right_quadrant_window_mac() -> bool:
 
 def bottom_right_quadrant_window_win():
     apply_window_fraction_win(0.5, 0.5, 0.5, 0.5)
+    return True
 
 
 # ===== (Tool 15) Left 2/3 Screen =====
@@ -830,6 +1119,7 @@ def left_two_thirds_window_mac() -> bool:
 
 def left_two_thirds_window_win():
     apply_window_fraction_win(0.0, 0.0, 2.0/3.0, 1.0)
+    return True
 
 
 # ===== (Tool 16) Right 2/3 Screen =====
@@ -842,3 +1132,33 @@ def right_two_thirds_window_mac() -> bool:
 
 def right_two_thirds_window_win():
     apply_window_fraction_win(1.0/3.0, 0.0, 2.0/3.0, 1.0)
+    return True
+
+
+def _frontmost_window_bounds_center_via_cg(pid: Optional[int]) -> Optional[Tuple[float, float]]:
+    """返回给定 pid 的最前普通窗口的中心点 (cx, cy)；失败返回 None。"""
+    if not _CGWINDOW_AVAILABLE or not pid:
+        return None
+    try:
+        options = kCGWindowListOptionOnScreenOnly | kCGWindowListExcludeDesktopElements
+        infos = CGWindowListCopyWindowInfo(options, 0) or []
+        for info in infos:
+            owner_pid = info.get('kCGWindowOwnerPID')
+            if int(owner_pid or -1) != int(pid):
+                continue
+            bounds = info.get('kCGWindowBounds') or {}
+            w = float(bounds.get('Width', 0) or 0)
+            h = float(bounds.get('Height', 0) or 0)
+            x = float(bounds.get('X', 0) or 0)
+            y = float(bounds.get('Y', 0) or 0)
+            alpha = info.get('kCGWindowAlpha', 1)
+            layer = int(info.get('kCGWindowLayer', 0) or 0)
+            # 仅选择普通窗口：有尺寸、可见、最上层（layer==0）
+            if w > 1 and h > 1 and alpha != 0 and layer == 0:
+                cx = x + w / 2.0
+                cy = y + h / 2.0
+                logger.info(f"_frontmost_window_bounds_center_via_cg: pid={pid} center=({cx},{cy})")
+                return (cx, cy)
+    except Exception:
+        pass
+    return None
